@@ -639,7 +639,7 @@ mod tests {
         let (env, _instance) = make_instance(TESTING_GAS_LIMIT);
         leave_default_data(&env);
 
-        assert_eq!(env.is_storage_readonly(), true);
+        assert!(env.is_storage_readonly());
     }
 
     #[test]
@@ -649,15 +649,15 @@ mod tests {
 
         // change
         env.set_storage_readonly(false);
-        assert_eq!(env.is_storage_readonly(), false);
+        assert!(!env.is_storage_readonly());
 
         // still false
         env.set_storage_readonly(false);
-        assert_eq!(env.is_storage_readonly(), false);
+        assert!(!env.is_storage_readonly());
 
         // change back
         env.set_storage_readonly(true);
-        assert_eq!(env.is_storage_readonly(), true);
+        assert!(env.is_storage_readonly());
     }
 
     #[test]
@@ -704,7 +704,7 @@ mod tests {
         let (env, _instance) = make_instance(TESTING_GAS_LIMIT);
         leave_default_data(&env);
 
-        env.call_function0("interface_version_5", &[]).unwrap();
+        env.call_function0("interface_version_7", &[]).unwrap();
     }
 
     #[test]
@@ -718,6 +718,7 @@ mod tests {
                 function_name,
                 expected,
                 actual,
+                ..
             } => {
                 assert_eq!(function_name, "allocate");
                 assert_eq!(expected, 0);
@@ -752,6 +753,7 @@ mod tests {
                 function_name,
                 expected,
                 actual,
+                ..
             } => {
                 assert_eq!(function_name, "deallocate");
                 assert_eq!(expected, 1);
